========
TorchKGE
========

.. image:: https://graphs.telecom-paristech.fr/images/logo_torchKGE_small.png
    :align: right
    :width: 100px
    :alt: logo torchkge

.. image:: https://img.shields.io/pypi/v/torchkge.svg
        :target: https://pypi.python.org/pypi/torchkge

.. image:: https://travis-ci.org/torchkge-team/torchkge.svg?branch=master
    :target: https://travis-ci.org/torchkge-team/torchkge

.. image:: https://readthedocs.org/projects/torchkge/badge/?version=latest
    :target: https://torchkge.readthedocs.io/en/latest/?badge=latest
    :alt: Documentation Status

.. image:: https://pyup.io/repos/github/torchkge-team/torchkge/shield.svg
     :target: https://pyup.io/repos/github/torchkge-team/torchkge/
     :alt: Updates



TorchKGE: Knowledge Graph embedding in Python and Pytorch.


* Free software: BSD license
* Documentation: https://torchkge.readthedocs.io.
